Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/__init__.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py	(revision 14178)
@@ -2,5 +2,5 @@
 """
 # Make this a package.
-from ikobacustom.skeleton.documents.document import SkeletonDocument
+from ikobacustom.uniben.documents.document import SkeletonDocument
 
 __all__ = [
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/document.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py	(revision 14178)
@@ -24,6 +24,6 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.documents.document import PublicDocumentBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
@@ -45,5 +45,5 @@
     grok.name(u'waeup.SkeletonDocument')
     title = u"Create a new document.",
-    description = u"This factory instantiates new skeleton documents."
+    description = u"This factory instantiates new uniben documents."
 
     def __call__(self, *args, **kw):
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/tests/test_browser.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py	(revision 14178)
@@ -27,8 +27,8 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.documents.tests.test_batching import DocumentImportExportSetup
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.export import SkeletonDocumentExporter
-from ikobacustom.skeleton.documents.batching import SkeletonDocumentProcessor
-from ikobacustom.skeleton.testing import FunctionalLayer
+from ikobacustom.uniben.documents.document import SkeletonDocument
+from ikobacustom.uniben.documents.export import SkeletonDocumentExporter
+from ikobacustom.uniben.documents.batching import SkeletonDocumentProcessor
+from ikobacustom.uniben.testing import FunctionalLayer
 
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/tests/test_document.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py	(revision 14178)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton documents.
+Tests for uniben documents.
 """
 from zope.interface.verify import verifyClass, verifyObject
@@ -23,7 +23,7 @@
 from waeup.ikoba.documents.container import DocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.uniben.documents.document import SkeletonDocument
+from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
 
 class SkeletonDocumentTestCase(FunctionalTestCase):
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/utils.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py	(revision 14178)
@@ -19,5 +19,5 @@
 """
 from waeup.ikoba.documents.utils import DocumentsUtils
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 

Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/batching.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py	(revision 14178)
@@ -16,10 +16,10 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.batching import DocumentProcessorBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
@@ -27,5 +27,5 @@
     """A batch processor for ISkeletonDocument objects.
     """
-    util_name = 'skeletondocumentprocessor'
+    util_name = 'unibendocumentprocessor'
     grok.name(util_name)
 
@@ -16,10 +16,10 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for uniben documents.
 """
 import grok
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/export.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py	(revision 14178)
@@ -16,10 +16,10 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.export import DocumentExporterBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
@@ -27,5 +27,5 @@
     """Exporter for documents.
     """
-    grok.name('skeletondocuments')
+    grok.name('unibendocuments')
     iface = ISkeletonDocument
     class_name = 'SkeletonDocument'
@@ -16,10 +16,10 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton documents.
+"""Exporters for uniben documents.
 """
 import grok
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/documents/interfaces.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py	(revision 14178)
@@ -17,9 +17,9 @@
 ##
 from waeup.ikoba.documents.interfaces import IPublicDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
 class ISkeletonDocument(IPublicDocument):
     """A representation of a skeleton document.
 
     """
@@ -17,9 +17,9 @@
 
 class ISkeletonDocument(IPublicDocument):
-    """A representation of a skeleton document.
+    """A representation of a uniben document.
 
     """